function [ Sa_VM ] = VM_Stress_Alt(Kf_bend, Sa_bend, Kf_axial, Sa_axial, Kfs, Ta )
%
%  This routine computed the von Mises alternating fatigue stress.  It is
%  based on equation 6-55 in Shigley
%
%    Kf_bend = the fatigue stress concentration factor for bending
%    Sa_bend = the alternating bending stress
%    Kf_axial = the fatique stress concentration factor for axial stress
%    Sa_axial = the alternating axial stress
%    Kfs = the stress concentration factor for torsion
%    Ta = the alternating torsion stress
%

Sa_VM = sqrt((Kf_bend*Sa_bend + Kf_axial * Sa_axial/0.85)^2 + 3*(Kfs*Ta)^2);

end

